<?php
/*
Copyright (c) 2020 HACKCHIK (https://hackchik.ru)
Developed by Andrey Chikaev (https://vk.com/winchikplay)
*/
class controlController extends Controller {
	public function index($serverid = null) {	
		$this->document->setActiveSection('admin');
		$this->document->setActiveItem('servers');
		
		if(!$this->user->isLogged()) {
			$this->session->data['error'] = "Вы не авторизированы!";
			$this->response->redirect($this->config->url . 'account/login');
		}
		if($this->user->getAccessLevel() < 2) {
			$this->session->data['error'] = "У вас нет доступа к данному разделу!";
			$this->response->redirect($this->config->url);
		}
		
		$this->load->library('query');
		$this->load->model('servers');
		$this->load->model('serversStats');
		
		$error = $this->validate($serverid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'servers/index');
		}
		
		$server = $this->serversModel->getServerById($serverid, array('users', 'games', 'locations'));
		$this->data['server'] = $server;
		
		if($server['server_status'] == 2) {
			$queryLib = new queryLibrary($server['game_query']);
			$queryLib->connect($server['location_ip'], $server['server_port']);
			$query = $queryLib->getInfo();
			$queryLib->disconnect();
			
			$this->data['query'] = $query;
		}
		
		$stats = $this->serversStatsModel->getServerStats($serverid, "NOW() - INTERVAL 1 DAY", "NOW()");
		$this->data['stats'] = $stats;
		
		$this->getChild(array('common/admheader', 'common/footer'));
		return $this->load->view('admin/servers/control', $this->data);
	}
	
	public function actionserver($serverid = null, $actionserver = null) {
		if(!$this->user->isLogged()) {
			$this->data['status'] = "error";
			$this->data['error'] = "Вы не авторизированы!";
			return json_encode($this->data);
		}
		if($this->user->getAccessLevel() < 2) {
			$this->data['status'] = "error";
			$this->data['error'] = "У вас нет доступа к данному разделу!";
			return json_encode($this->data);
		}
		
		$this->load->library('mail');
		$this->load->library('ssh2');		
		$this->load->model('servers');
		$this->load->model('serverLog');
		$this->load->model('serversStats');
		$this->load->model('serversOwners');
		$this->load->model('serversFirewalls');
		$this->load->model('serverLog');
		
		$error = $this->validate($serverid);
		if($error) {
			$this->data['status'] = "error";
			$this->data['error'] = $error;
			return json_encode($this->data);
		}
		
		$server = $this->serversModel->getServerById($serverid, array('users', 'locations', 'games'));	

		$mailLib = new mailLibrary();
		
		$mailLib->setFrom($this->config->mail_from);
		$mailLib->setSender($this->config->mail_sender);
		
		switch($actionserver) {
			case "start": {
				if($server["server_status"] == 1) {
					$stats = $this->serversModel->getHDD($server['server_id']);
					if((int)$stats < $server['game_ssd']) {
						$result = $this->serversModel->action($serverid, 'start');
						if($result["status"] == "success") {
							$this->serversModel->updateServer($serverid, array("server_status" => 2));
							$logData = array(
								'server_id'			=> $serverid,
								'reason'            => 'Успешный запуск сервера',
								'status'            => 1
							);
							$this->serverLogModel->createLog($logData);
							$today = date("Y-m-d H:i:s");
							$this->serversModel->updateServer($serverid, array('server_ssd_load' => (int)$stats, 'server_ssd_date'   =>	$today));
							$this->data["status"] = "success";
							$this->data["success"] = "Вы успешно запустили сервер!";
						} else {
							$this->data["status"] = "error";
							$this->data["error"] = $result["description"];
						}
					} else {
						$this->data["status"] = "error";
						$this->data["error"] = "Вы привысили ограничение размера директории на ". round($stats - $server['game_ssd'], 2) ."МБ, запуск сервера невозможен!";
					}
				} else if($server["server_status"] == 0) {
					$this->data["status"] = "error";
					$this->data["error"] = "Сервер не оплачен!";
				} else if($server["server_status"] == 2) {
					$this->data["status"] = "error";
					$this->data["error"] = "Сервер должен быть выключен!";
				} else if($server["server_status"] == 0) {
					$this->data["status"] = "error";
					$this->data["error"] = "Сервер заблокирован!";
				}
				break;
			}
				
			case "reinstall": {
				if($server["server_status"] == 1) {
					$result = $this->serversModel->action($serverid, 'reinstall');
					if($result["status"] == "success") {
						$logData = array(
							'server_id'			=> $serverid,
							'reason'            => 'Успешная переустановка сервера',
							'status'            => 2
						);
                        $this->serverLogModel->createLog($logData);
						$stats = $this->serversModel->getHDD($server['server_id']);		
						$today = date("Y-m-d H:i:s");
						$this->serversModel->updateServer($serverid, array('server_ssd_load' => (int)$stats, 'server_ssd_date'   =>	$today));
						$this->data["status"] = "success";
						$this->data["success"] = "Вы успешно переустановили сервер!";
					} else {
						$this->data["status"] = "error";
						$this->data["error"] = $result["description"];
					}
				} else if($server["server_status"] == 2) {
					$this->data["status"] = "error";
					$this->data["error"] = "Сервер должен быть выключен!";
				} else if($server["server_status"] == 0) {
					$this->data["status"] = "error";
					$this->data["error"] = "Сервер заблокирован!";
				}
				break;
			}
				
			case "restart": {
				if($server["server_status"] == 2) {
					$stats = $this->serversModel->getHDD($server['server_id']);
					if((int)$stats < $server['game_ssd']) {
						$this->serversModel->action($serverid, 'stop');
						$result = $this->serversModel->action($serverid, 'start');
						if($result["status"] == "success") {
							$logData = array(
								'server_id'			=> $serverid,
								'reason'            => 'Успешный перезапуск сервера',
								'status'            => 1
							);
							$this->serverLogModel->createLog($logData);
							$today = date("Y-m-d H:i:s");
							$this->serversModel->updateServer($serverid, array('server_ssd_load' => (int)$stats, 'server_ssd_date'   =>	$today));
							$this->data["status"] = "success";
							$this->data["success"] = "Вы успешно перезапустили сервер!";
						} else {
							$this->data["status"] = "error";
							$this->data["error"] = $result["description"];
						}
					} else {
						$result = $this->serversModel->action($serverid, 'stop');
						if($result['status'] == "success") {
							$this->serversModel->updateServer($serverid, array('server_status' => 2));
							$this->data["status"] = "error";
							$this->data["error"] = "Вы привысили ограничение размера директории на ". round($stats - $server['game_ssd'], 2) ."МБ, перезагрузка сервера невозможен!";
						} else {
							$this->data["status"] = "error";
							$this->data["error"] = $result["description"];
						}
					}
				} else if($server["server_status"] == 2) {
					$this->data["status"] = "error";
					$this->data["error"] = "Сервер должен быть выключен!";
				} else if($server["server_status"] == 0) {
					$this->data["status"] = "error";
					$this->data["error"] = "Сервер заблокирован!";
				}
				break;
			}
			
			case "stop": {
				if($server["server_status"] == 2) {
					$result = $this->serversModel->action($serverid, 'stop');
					if($result["status"] == "success") {
						$this->serversModel->updateServer($serverid, array("server_status" => 1));
						$logData = array(
							'server_id'			=> $serverid,
							'reason'            => 'Успешное выключение сервера',
							'status'            => 1
						);
                        $this->serverLogModel->createLog($logData);	
						$stats = $this->serversModel->getHDD($server['server_id']);
						$today = date("Y-m-d H:i:s");
						$this->serversModel->updateServer($serverid, array('server_ssd_load' => (int)$stats, 'server_ssd_date'   =>	$today));
						$this->data["status"] = "success";
						$this->data["success"] = "Вы успешно выключили сервер!";
					} else {
						$this->data["status"] = "error";
						$this->data["error"] = $result["description"];
					}
				} else if($server["server_status"] == 2) {
					$this->data["status"] = "error";
					$this->data["error"] = "Сервер должен быть выключен!";
				} else if($server["server_status"] == 0) {
					$this->data["status"] = "error";
					$this->data["error"] = "Сервер заблокирован!";
				}
				break;
			}

			case 'backup': {
				if($server['server_status'] == 1) {
					$stats = $this->serversModel->getHDD($server['server_id']);
					if((int)$stats < $server['game_ssd']) {
						$this->serversModel->updateServer($serverid, array('server_status' => 5));
						$logData = array(
							'server_id'			=> $serverid,
							'reason'            => 'Успешное начало создания BackUP сервера.',
							'status'            => 1
						);
						$this->serverLogModel->createLog($logData);
						$this->data['status'] = "success";
						$this->data['success'] = "Вы успешно начали создание BackUP сервера!";
					} else {
						$this->data["status"] = "error";
						$this->data["error"] = "Вы привысили ограничение размера директории на ". round($stats - $server['game_ssd'], 2) ."МБ, создание бекапа сервера невозможено!";
					}
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "Сервер должен быть выключен!";
				}
				break;
			}
			
			case 'unbackup': {
				if($server['server_status'] == 1) {
					if (file_exists('ssh2.sftp://'.$server['location_user'].':'.$server['location_password'].'@'.$server['location_ip'].':22/home/cp/backups/gs'.$serverid.'.tar')) {
						$result = $this->serversModel->action($serverid, 'installbackup');
						$this->serversModel->updateServer($serverid, array('server_status' => 6));
						$logData = array(
							'server_id'			=> $serverid,
							'reason'            => 'Успешное начало восстановление BackUP сервера.',
							'status'            => 1
						);
						$this->serverLogModel->createLog($logData);
						$stats = $this->serversModel->getHDD($server['server_id']);		
						$today = date("Y-m-d H:i:s");
						$this->serversModel->updateServer($serverid, array('server_ssd_load' => (int)$stats, 'server_ssd_date'   =>	$today));
						$this->data['status'] = "success";
						$this->data['success'] = "Вы успешно восстановили BackUP сервера!";
					} else {
						$this->data['status'] = "error";
						$this->data['error'] = "У вас нет BackUP сервера!";
					}
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "Сервер должен быть выключен!";
				}
				break;
			}
			
			case 'block': {
				if($server['server_status'] == 1) {
					$this->serversModel->updateServer($serverid, array('server_status' => 0));
					$this->serversModel->action($serverid, "block");
					$this->data['status'] = "success";
					$this->data['success'] = "Вы успешно заблокировали сервер!";
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "Сервер должен быть выключен!";
				}
				break;
			}
			case 'delete': {
				if($server['server_status'] == 1) {
					if($this->user->getAccessLevel() == 3){
						$result = $this->serversModel->action($serverid, 'delete');
						if($result['status'] == "success") {
							if($server['server_mysql'] ==  1 || $server['server_mysql'] ==  2) {
								$this->serversModel->action($serverid, "delete_mysql");
							}
							$this->serversModel->deleteServer($serverid);
							$this->serversStatsModel->deleteServerStats($serverid);
							$this->serversOwnersModel->deleteserverOwners($serverid);
							$this->serverLogModel->deleteLog($serverid);
							
							$firewall = $this->serversFirewallsModel->getFirewallsById($serverid);

							if ($firewall) {
								foreach ($firewall as $item2) {
									$ssh2Lib = new ssh2Library();
									$link = $ssh2Lib->connect($server['location_ip'], $server['location_user'], $server['location_password']);
									
									$ssh2Lib->execute($link, "iptables -D INPUT -s ".$item2['server_ip']." -p udp -d ".$server['location_ip']." --dport ".$server['server_port']." -j DROP;");
									$ssh2Lib->execute($link, "iptables -D INPUT -s ".$item2['server_ip']." -p tcp -d ".$server['location_ip']." --dport ".$server['server_port']." -j DROP;");
									
									$ssh2Lib->disconnect($link);
									
									$this->serversFirewallsModel->deleteFirewallDB($item2['firewall_id']);
								}
							}
							
							$mailLib->setTo($server['user_email']);
							$mailLib->setSubject("Удаление сервера администратором #$serverid");
										
							$mailData = array();
							$mailData['firstname'] = $server['user_firstname'];
							$mailData['lastname'] = $server['user_lastname'];
							$mailData['serverid'] = $serverid;
											
							$text = $this->load->view('mail/servers/deleted', $mailData);
										
							$mailLib->setText($text);
							$mailLib->send();

							$this->data['status'] = "success";
							$this->data['success'] = "Вы успешно удалили сервер!";
						} else {
							$this->data['status'] = "error";
							$this->data['error'] = $result['description'];
						}
					} else {
						$this->session->data['error'] = "У вас нет доступа к данному разделу!";
						$this->response->redirect($this->config->url);
					}
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "Сервер должен быть выключен!";
				}
				break;
			}
			case 'unblock': {
				if($server['server_status'] == 0) {
					$this->serversModel->updateServer($serverid, array('server_status' => 1));
					$this->serversModel->action($serverid, "updatepassm");
					$this->serversModel->action($serverid, "updatepass");
					$this->data['status'] = "success";
					$this->data['success'] = "Вы успешно разблокировали сервер!";
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "Сервер должен быть заблокированн!";
				}
				break;
			}
			default: {
				$this->data['status'] = "error";
				$this->data['error'] = "Вы выбрали несуществующее действие!";
				break;
			}
		}
		
		return json_encode($this->data);
	}
	
	private function validate($serverid) {
		$result = null;
		
		if(!$this->serversModel->getTotalServers(array('server_id' => (int)$serverid))) {
			$result = "Запрашиваемый сервер не существует!";
		}
		return $result;
	}
	
	private function validatePOST() {
		$this->load->library('validate');
		
		$validateLib = new validateLibrary();
		
		$result = null;
		
		$slots = @$this->request->post['slots'];
		$editpassword = @$this->request->post['editpassword'];
		$password = @$this->request->post['password'];
		$password2 = @$this->request->post['password2'];
		
		if($editpassword) {
			if(!$validateLib->password($password)) {
				$result = "Пароль должен содержать от 6 до 32 латинских букв, цифр и знаков <i>,.!?_-</i>!";
			}
			elseif($password != $password2) {
				$result = "Введенные вами пароли не совпадают!";
			}
		}
		return $result;
	}

	public function mysqlhostin($serverid = null, $mysqlhostin = null) {
		if(!$this->user->isLogged()) {
			$this->data['status'] = "error";
			$this->data['error'] = "Вы не авторизированы!";
			return json_encode($this->data);
		}
		if($this->user->getAccessLevel() < 0) {
	  		$this->data['status'] = "error";
			$this->data['error'] = "У вас нет доступа к данному разделу!";
			return json_encode($this->data);
		}
		
		$this->load->model('servers');
		
		$error = $this->validate($serverid);
		if($error) {
			$this->data['status'] = "error";
			$this->data['error'] = $error;
			return json_encode($this->data);
		}
		
		$server = $this->serversModel->getServerById($serverid);
		switch($mysqlhostin) {
			case 'mysqlon': {
				if($server['server_mysql'] == 2) {
					$this->serversModel->updateServer($serverid, array('server_mysql' => 1));
					$this->data['status'] = "success";
					$this->data['success'] = "Вы успешно включили MySQL!";
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "MySQL и так включен либо вы его еще не создали!";
				}
				break;
			}	
			case 'mysqloff': {
				if($server['server_mysql'] == 1) {
					$this->serversModel->updateServer($serverid, array('server_mysql' => 2));
					$this->data['status'] = "success";
					$this->data['success'] = "Вы успешно выключили MySQL!";
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "MySQL и так выключен!";
				}
				break;
			}		
			case 'mysqlcr': {
				if($server['server_mysql'] == 0) {
					$this->serversModel->action($serverid, 'create_mysql');
					$this->serversModel->updateServer($serverid, array('server_mysql' => 2));
					$this->data['status'] = "success";
					$this->data['success'] = "Вы успешно создали MySQL! (БД: gs$serverid)";
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "MySQL и так создан!";
				}
				break;
			}				
			default: {
				$this->data['status'] = "error";
				$this->data['error'] = "Вы выбрали несуществующее действие!";
				break;
			}
		}
		
		return json_encode($this->data);
	}
}
?>
