<?php
/*

Copyright (c) 2020 HACKCHIK (https://hackchik.ru)

Developed by Andrey Chikaev (https://vk.com/winchikplay)

*/
class editController extends Controller {
	public function index($versionid = null) {
		if(!$this->user->isLogged()) {
			$this->session->data['error'] = "Вы не авторизированы!";
			$this->response->redirect($this->config->url . 'account/login');
		}
		if($this->user->getAccessLevel() < 3) {
			$this->session->data['error'] = "У вас нет доступа к данному разделу!";
			$this->response->redirect($this->config->url);
		}
		
		$this->load->model('versions');
		
		$error = $this->validate($versionid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'admin/versions/index');
		}
		
		$version = $this->versionsModel->getVersionById($versionid);
		
		$this->data['version'] = $version;
		$this->load->model('games');
		$options = array(
			'start' => 0,
			'limit' => $this->limit
		);
		$games = $this->gamesModel->getGames(array(), array(), $options);
		$this->data['games'] = $games;
		$this->getChild(array('common/admheader', 'common/footer'));
		return $this->load->view('admin/versions/edit', $this->data);
	}
	
	public function ajax($versionid = null) {
		if(!$this->user->isLogged()) {  
	  		$this->data['status'] = "error";
			$this->data['error'] = "Вы не авторизированы!";
			return json_encode($this->data);
		}
		if($this->user->getAccessLevel() < 3) {
			$this->data['status'] = "error";
			$this->data['error'] = "У вас нет доступа к данному разделу!";
			return json_encode($this->data);
		}
		
		$this->load->model('versions');
		
		$error = $this->validate($versionid);
		if($error) {
			$this->data['status'] = "error";
			$this->data['error'] = $error;
			return json_encode($this->data);
		}
		
		if($this->request->server['REQUEST_METHOD'] == 'POST') {
			$errorPOST = $this->validatePOST();
			if(!$errorPOST) {
				$name = @$this->request->post['name'];
				$gameid = @$this->request->post['gameid'];
				$gameidto = @$this->request->post['gameidto'];
				$status = @$this->request->post['status'];
				$price = @$this->request->post['price'];
			
				$versionData = array(
					'game_id'			=> $gameid,
					'version_name'		=> $name,
					'game_id_to'		=> $gameidto,
					'version_status'	=> (int)$status,
					'version_price'	    => $price
				);		
				$this->versionsModel->updateVersion($versionid, $versionData);						
				$this->data['status'] = "success";
				$this->data['success'] = "Вы успешно отредактировали смену игры!";
			} else {
				$this->data['status'] = "error";
				$this->data['error'] = $errorPOST;
			}
		}

		return json_encode($this->data);
	}
	
	public function delete($versionid = null) {
		$this->document->setActiveSection('admin');
		$this->document->setActiveItem('versions');
		
		if(!$this->user->isLogged()) {
			$this->session->data['error'] = "Вы не авторизированы!";
			$this->response->redirect($this->config->url . 'account/login');
		}
		if($this->user->getAccessLevel() < 3) {
			$this->session->data['error'] = "У вас нет доступа к данному разделу!";
			$this->response->redirect($this->config->url);
		}
		
		$this->load->model('versions');
		
		$error = $this->validate($versionid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'admin/versions/index');
		}
		
		$this->versionsModel->deleteVersion($versionid);
		
		$this->session->data['success'] = "Вы успешно удалили смену игры!";
		$this->response->redirect($this->config->url . 'admin/versions/index');
		return null;
	}
	
	private function validate($versionid) {
		$result = null;
		
		if(!$this->versionsModel->getTotalVersions(array('version_id' => (int)$versionid))) {
			$result = "Запрашиваемая смена игры не существует!";
		}
		return $result;
	}
	
	private function validatePOST() {
		$this->load->library('validate');
		
		$validateLib = new validateLibrary();
		
		$result = null;
		
		$name = @$this->request->post['name'];
        $gameid = @$this->request->post['gameid'];
        $status = @$this->request->post['status'];
        $price = @$this->request->post['price'];
        $category = @$this->request->post['category'];
		
		if(mb_strlen($name) < 2 || mb_strlen($name) > 32) {
            $result = "Название смены игры должно содержать от 2 до 32 символов!";
        }
        elseif($status < 0 || $status > 1) {
            $result = "Укажите допустимый статус!";
        }
        elseif(0 > $price || $price > 5000) {
            $result = "Укажите сумму от 0 до 5000 рублей!";
        }

		return $result;
	}
}
?>
