<?php
/*

Copyright (c) 2020 HACKCHIK (https://hackchik.ru)

Developed by Andrey Chikaev (https://vk.com/winchikplay)

*/
class consoleController extends Controller {
	public function index($serverid = null) {
		$this->document->setActiveSection('servers');
		$this->document->setActiveItem('console');

		if(!$this->user->isLogged()) {
			$this->session->data['error'] = "Вы не авторизированы!";
			$this->response->redirect($this->config->url . 'account/login');
		}
		if($this->user->getAccessLevel() < 0) {
			$this->session->data['error'] = "У вас нет доступа к данному разделу!";
			$this->response->redirect($this->config->url);
		}
		
		if(isset($this->request->get['open'])) {
			$this->data['fileid'] = $this->request->get['open'];
		}
		
		$this->load->model('servers');

		$error = $this->validate($serverid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'servers/index');
		}
		
		$server = $this->serversModel->getServerById($serverid, array('games', 'locations'));
		$this->data['server'] = $server;
		
		if(isset($_COOKIE["data-theme-console"])){
			$this->data['theme'] = $_COOKIE['data-theme-console'];
		} else{
			$this->data['theme'] = "color: white; background-color: black; font-family: Inconsolata; resize: none; min-height: 300px;";
		}
		
		include_once 'application/controllers/common/main.php';

		$this->getChild(array('common/header', 'common/footer'));
		return $this->load->view('servers/console', $this->data);
	}

	public function getconsole($serverid = null, $file = null) {
		if(!$this->user->isLogged()) {
			$this->data['status'] = "error";
			$this->data['error'] = "Вы не авторизированы!";
			return json_encode($this->data);
		}
		if($this->user->getAccessLevel() < 1) {
			$this->data['status'] = "error";
			$this->data['error'] = "У вас нет доступа к данному разделу!";
			return json_encode($this->data);
		}

		$this->load->model('servers');
		$this->load->library('ssh2');

		$server = $this->serversModel->getServerById($serverid, array('games', 'locations'));

		$error = $this->validate($serverid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'servers/index');
		}
		
		if($server["server_status"] == 0) {
			$this->data["status"] = "error";
			$this->data["error"] = "Сервер заблокирован!";
			return json_encode($this->data);
		}
		
		$ssh = new ssh2Library();
		$connect = $ssh->connect($server['location_ip'], $server['location_user'], $server['location_password']);
		
		switch($file) {
			case 'samp_1': {
				$fileLog = "server_log.txt";
				break;
			}
			case 'samp_2': {					
				$fileLog = "mysql_log.txt";
				break;
			}
			case 'crmp_1': {					
				$fileLog = "server_log.txt";
				break;
			}
			case 'mtasa_1': {					
				$fileLog = "mods/deathmatch/logs/server.log";
				break;
			}
			case 'Hurtworld_1': {					
				$fileLog = "output.txt";
				break;
			}
			default: {
				$fileLog = "screenlog.0";
				break;
			}
		}

		$screenlog = $ssh->get($connect, "iconv -f windows-1251 -t utf8 /home/gs".$server['server_id']."/".$fileLog);
		$ssh->disconnect($connect);
				
		return $screenlog;
	}		

	public function sendconsole($serverid = null) {
		if(!$this->user->isLogged()) {
			$this->data['status'] = "error";
			$this->data['error'] = "Вы не авторизированы!";
			return json_encode($this->data);
		}
		if($this->user->getAccessLevel() < 1) {
			$this->data['status'] = "error";
			$this->data['error'] = "У вас нет доступа к данному разделу!";
			return json_encode($this->data);
		}

		$this->load->model('servers');
		$this->load->library('ssh2');

		$server = $this->serversModel->getServerById($serverid, array('games', 'locations'));

		$error = $this->validate($serverid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'servers/index');
		}
		
		if($server["server_status"] == 0) {
			$this->data["status"] = "error";
			$this->data["error"] = "Сервер заблокирован!";
			return json_encode($this->data);
		}
		
		$command = @$this->request->post['cmd'];

		if($server['server_status'] == 2){
			if($command == ""){
				$this->data['status'] = "error";
				$this->data['error'] = "Введите команду!";
			}elseif($command != ""){
				if($server['game_query'] == "samp") {
					$this->load->library('SampRconAPI');
					
					$cfg = file_get_contents('ftp://gs'.$server['server_id'].':'.$server['server_password'].'@'.$server['location_ip'].':21/server.cfg');
					$pass = explode("\n",$cfg);
					$pass = substr($pass[2], 14);
					
					$SampRcon = new SampRconAPI($server['location_ip'], $server['server_port'], $pass);
					if ($SampRcon->connect()) {
						$SampRcon->call($command, false);
						
						$this->data['status'] = "success";
						$this->data['success'] = "Команда успешно отправлена!";
					} else { 
						$this->data['status'] = "error";
						$this->data['error'] = "Ошибка подключения к rcon!";
					}
					$SampRcon->close();
				} else {					
					$exec = str_replace("'", "&#039;", $command);
					$this->serversModel->action($serverid, 'sendcommand', array('command' => $exec));
					
					$this->data['status'] = "success";
					$this->data['success'] = "Команда успешно отправлена!";
				}
			}
		}else{
			$this->data['status'] = "error";
			$this->data['error'] = "Сервер должен быть включён!";
		}
		return json_encode($this->data);
	}
	
	public function clearcon($serverid = null) {
		if(!$this->user->isLogged()) {  
	  		$this->data['status'] = "error";
			$this->data['error'] = "Вы не авторизированы!";
			return json_encode($this->data);
		}
		if($this->user->getAccessLevel() < 1) {
	  		$this->data['status'] = "error";
			$this->data['error'] = "У вас нет доступа к данному разделу!";
			return json_encode($this->data);
		}
		
		$this->load->model('servers');		
		$this->load->library('ssh2');
		
		$server = $this->serversModel->getServerById($serverid, array('games','locations'));	
		
		$error = $this->validate($serverid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'servers/index');
		}
				
		if($server["server_status"] == 0) {
			$this->data["status"] = "error";
			$this->data["error"] = "Сервер заблокирован!";
			return json_encode($this->data);
		}
		
		if($this->request->server['REQUEST_METHOD'] == 'POST') {		   
			if($server['server_status'] == 2) {
				$ssh2Lib = new ssh2Library();
				$link = $ssh2Lib->connect($server['location_ip'], $server['location_user'], $server['location_password']);
				if($server['game_query'] == 'samp') {				
					$output = $ssh2Lib->execute($link, "echo 'Console clear!' > /home/gs$serverid/server_log.txt;");
				}
				if($server['game_query'] == 'valve') {				
					$output = $ssh2Lib->execute($link, "echo 'Консоль успешно очищена!' > /home/gs$serverid/screenlog.0;");
				}
				if($server['game_code'] == 'mcpe') {				
					$output = $ssh2Lib->execute($link, "echo 'Консоль успешно очищена!' > /home/gs$serverid/server.log;");
				}
				if($server['game_code'] == 'mtasa') {				
					$output = $ssh2Lib->execute($link, "echo 'Консоль успешно очищена!' > /home/gs$serverid/screenlog.0;");
				}
				$ssh2Lib->disconnect($link);
				$this->data['status'] = "success";
				$this->data['success'] = "Консоль успешно очищена!";
			} else {
				$this->data['status'] = "error";
				$this->data['error'] = "Сервер должен быть включен!";
			}
		}
		return json_encode($this->data);
	}
	
	public function action_theme_console($action = null) {
		if(!$this->user->isLogged()) {
			$this->data['status'] = "error";
			$this->data['error'] = "Вы не авторизированы!";
			return json_encode($this->data);
		}
		if($this->user->getAccessLevel() < 1) {
			$this->data['status'] = "error";
			$this->data['error'] = "У вас нет доступа к данному разделу!";
			return json_encode($this->data);
		}

		switch($action) {
			case 'default': {	
					$name = 'color: white; background-color: black; font-family: Inconsolata; resize: none; min-height: 300px;';
					setcookie('data-theme-console',$name,time() + (86400 * 5), '/' );
					$this->data['status'] = "success";
					$this->data['success'] = "Тема установлена!";
				break;
			}
			case 'Amethyst': {	
					$name = 'color: #323e42; background-color: #a48ad4; font-family: Inconsolata; resize: none; min-height: 300px;';
					setcookie('data-theme-console',$name,time() + (86400 * 5), '/' );
					$this->data['status'] = "success";
					$this->data['success'] = "Тема установлена!";
				break;
			}
			case 'City': {	
					$name = 'color: #323e42; background-color: #ff6b6b; font-family: Inconsolata; resize: none; min-height: 300px;';
					setcookie('data-theme-console',$name,time() + (86400 * 5), '/' );
					$this->data['status'] = "success";
					$this->data['success'] = "Тема установлена!";
				break;
			}
			case 'Flat': {	
					$name = 'color: #323e42; background-color: #44b4a6; font-family: Inconsolata; resize: none; min-height: 300px;';
					setcookie('data-theme-console',$name,time() + (86400 * 5), '/' );
					$this->data['status'] = "success";
					$this->data['success'] = "Тема установлена!";
				break;
			}
			case 'Modern': {	
					$name = 'color: #323e42; background-color: #14adc4; font-family: Inconsolata; resize: none; min-height: 300px;';
					setcookie('data-theme-console',$name,time() + (86400 * 5), '/' );
					$this->data['status'] = "success";
					$this->data['success'] = "Тема установлена!";
				break;
			}
			case 'Smooth': {	
					$name = 'color: #323e42; background-color: #ff6c9d; font-family: Inconsolata; resize: none; min-height: 300px;';
					setcookie('data-theme-console',$name,time() + (86400 * 5), '/' );
					$this->data['status'] = "success";
					$this->data['success'] = "Тема установлена!";
				break;
			}
			default: {
				$this->data['status'] = "error";
				$this->data['error'] = "Вы выбрали несуществующее действие!";
				break;
			}
		}

		return json_encode($this->data);
	}
	
	function validate($serverid) {
		$result = null;
		$this->user->getId(  );
		$userid = $this->user->getId();

		if(!$this->serversModel->getTotalServerOwners(array('server_id' => (int)$serverid, 'user_id' => (int)$userid, 'owner_status' => 1))) {
			if(!$this->serversModel->getTotalServers(array('server_id' => (int)$serverid, 'user_id' => (int)$userid))) {
				$result = "Запрашиваемый сервер не существует!";
			}
		}
		return $result;
	}
		
	private function validatePOST() {
		$this->load->library('validate');
		
		$validateLib = new validateLibrary();
		
		$result = null;
		return $result;
	}
}