<?php
/*

Copyright (c) 2020 HACKCHIK (https://hackchik.ru)

Developed by Andrey Chikaev (https://vk.com/winchikplay)

*/
class ftpController extends Controller {
	public function index($serverid = null) {
		$this->document->setActiveSection('servers');
		$this->document->setActiveItem('ftp');

		if(!$this->user->isLogged()) {
			$this->session->data['error'] = "Вы не авторизированы!";
			$this->response->redirect($this->config->url . 'account/login');
		}
		
		if($this->user->getAccessLevel() < 0) {
			$this->session->data['error'] = "У вас нет доступа к данному разделу!";
			$this->response->redirect($this->config->url);
		}
		
		$this->load->model('servers');
		
		$error = $this->validate($serverid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'servers/index');
		}
		
		$server = $this->serversModel->getServerById($serverid, array('games', 'locations'));
		$this->data['server'] = $server;
		
		if(isset($_COOKIE["data-theme-ftp"])){
			$this->data['theme'] = $_COOKIE['data-theme-ftp'];
		} else{
			$this->data['theme'] = "/application/public/css/theme.css";
		}
		
		include_once 'application/controllers/common/main.php';
		
		$this->getChild(array('common/header', 'common/footer'));
		return $this->load->view('servers/ftp', $this->data);
	}
	
	public function action_theme_ftp($action = null) {
		if(!$this->user->isLogged()) {
			$this->data['status'] = "error";
			$this->data['error'] = "Вы не авторизированы!";
			return json_encode($this->data);
		}
		
		if($this->user->getAccessLevel() < 1) {
			$this->data['status'] = "error";
			$this->data['error'] = "У вас нет доступа к данному разделу!";
			return json_encode($this->data);
		}
		
		$this->load->model('servers');

		switch($action) {
			case 'default': {	
					$name = '/application/public/css/theme.css';
					setcookie('data-theme-ftp',$name,time() + (86400 * 5), '/' );
					$this->data['status'] = "success";
					$this->data['success'] = "Тема установлена!";
				break;
			}
			case 'windows': {	
					$name = '/application/public/css/elfinderT/windows-10/css/theme.css';
					setcookie('data-theme-ftp',$name,time() + (86400 * 5), '/' );
					$this->data['status'] = "success";
					$this->data['success'] = "Тема установлена!";
				break;
			}
			case 'material': {	
					$name = '/application/public/css/elfinderT/Material/css/theme.css';
					setcookie('data-theme-ftp',$name,time() + (86400 * 5), '/' );
					$this->data['status'] = "success";
					$this->data['success'] = "Тема установлена!";
				break;
			}
			case 'materialgray': {	
					$name = '/application/public/css/elfinderT/Material/css/theme-gray.css';
					setcookie('data-theme-ftp',$name,time() + (86400 * 5), '/' );
					$this->data['status'] = "success";
					$this->data['success'] = "Тема установлена!";
				break;
			}
			default: {
				$this->data['status'] = "error";
				$this->data['error'] = "Вы выбрали несуществующее действие!";
				break;
			}
		}

		return json_encode($this->data);
	}
	
	private function validate($serverid) {
		$result = null;
		
		$userid = $this->user->getId();
		
		if(!$this->serversModel->getTotalServerOwners(array('server_id' => (int)$serverid, 'user_id' => (int)$userid, 'owner_status' => 1))) {
			if(!$this->serversModel->getTotalServers(array('server_id' => (int)$serverid, 'user_id' => (int)$userid))) {
				$result = "Запрашиваемый сервер не существует!";
			}
		}
		return $result;
	}
	
	

	public function getftp($serverid = null) {
		if(!$this->user->isLogged()) {
		    $this->session->data['error'] = "Вы не авторизированы!";
		    $this->response->redirect($this->config->url . 'account/login');
	    }
		
		if($this->user->getAccessLevel() < 0) {
		    $this->session->data['error'] = "У вас нет доступа к данному разделу!";
		    $this->response->redirect($this->config->url);
	    }
		  
		$this->load->model('servers');
  
		$server = $this->serversModel->getServerById($serverid, array('games', 'locations'));  
		
		$error = $this->validate($serverid);
		if($error) {
			$this->data['status'] = "error";
			$this->data['error'] = $error;
			return json_encode($this->data);
		}	
		
		if($server["server_status"] == 0) {
			$this->data["status"] = "error";
			$this->data["error"] = "Сервер заблокирован!";
			return json_encode($this->data);
		}
  
		include_once 'engine_ftp/elFinderConnector.class.php';
		include_once 'engine_ftp/elFinder.class.php';
	    include_once 'engine_ftp/elFinderVolumeDriver.class.php';
	    include_once 'engine_ftp/elFinderVolumeLocalFileSystem.class.php';
		include_once 'engine_ftp/elFinderVolumeFTP.class.php';
 
		function access($attr, $path, $data, $volume) {
			return strpos(basename($path), '.') === 0       // if file/folder begins with '.' (dot)
				? !($attr == 'read' || $attr == 'write')    // set read+write to false, other (locked+hidden) set to true
				:  null;                                    // else elFinder decide it itself
		}
		
		function logger($cmd, $result, $args, $elfinder) {
			$log = sprintf('[%s] %s:', date('r'), strtoupper($cmd));
			foreach ($result as $key => $value) {
				if (empty($value)) {
					continue;
				}
				$data = array();
				if (in_array($key, array('error', 'warning'))) {
					array_push($data, implode(' ', $value));
				} else {
					if (is_array($value)) { // changes made to files
						foreach ($value as $file) {
							$filepath = (isset($file['realpath']) ? $file['realpath'] : $elfinder->realpath($file['hash']));
							array_push($data, $filepath);
						}
					} else { // other value (ex. header)
						array_push($data, $value);
					}
				}
				$log .= sprintf(' %s(%s)', $key, implode(', ', $data));
			}
			$log .= "\n";

			$logfile = 'files/log.txt';
			$dir = dirname($logfile);
			if (!is_dir($dir) && !mkdir($dir)) {
				return;
			}
			if (($fp = fopen($logfile, 'a'))) {
				fwrite($fp, $log);
				fclose($fp);
			}
		}
		
       $opts = array(
				'roots' => array(
				array(
					'driver' => 'FTP',
					'URL' => 'ftp://gs'.$server['server_id'].':'.$server['server_password'].'@'.$server['location_ip'].':21/',
					'host'   => $server['location_ip'],
					'user'   => 'gs'.$server['server_id'],
					'pass'   => $server['server_password'],
					'port'   => 21,  
					'mode'   => 'passive',
					'path'   => '/',
					'read' => true,
					'write' => true,
					'utf8fix' => true,
					'bind' => array(
					'mkdir mkfile rename duplicate upload rm paste' => 'logger'
				),
				'rootAlias'=>'Server Root',
				'fileURL'=>True,
				'dotFiles'=>True,
				'dirSize'=>True,
				'fileMode'=>0644,
				'dirMode'=>0775,
				'imgLib'=>False,
				'tmbDir'=>'.tmb',
				'tmbAtOnce'=>5,
				'debug'=>True
				),
				'attributes' => array(
					array(
						'pattern' => '~/\.~',
						'read' => true,
						'write' => true,
						'hidden' => true	
					),		
				)
			)
		);

		$connector = new elFinderConnector(new elFinder($opts));
		$connector->run();
	}

}
?>
