<?php
/*

Copyright (c) 2020 HACKCHIK (https://hackchik.ru)

Developed by Andrey Chikaev (https://vk.com/winchikplay)

*/
class mysqlController extends Controller {
	public function index($serverid = null) {
		$this->document->setActiveSection('servers');
		$this->document->setActiveItem('mysql');
		
		if(!$this->user->isLogged()) {
			$this->session->data['error'] = "Вы не авторизированы!";
			$this->response->redirect($this->config->url . 'account/login');
		}
		if($this->user->getAccessLevel() < 0) {
			$this->session->data['error'] = "У вас нет доступа к данному разделу!";
			$this->response->redirect($this->config->url);
		}

		$this->load->model('servers');
		
		$error = $this->validate($serverid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'servers/index');
		}

		$server = $this->serversModel->getServerById($serverid, array('games', 'locations'));
		$this->data['server'] = $server;
		
		include_once 'application/controllers/common/main.php';
	
		$this->getChild(array('common/header', 'common/footer'));
		return $this->load->view('servers/mysql', $this->data);
	}
	
	public function action($serverid = null, $action = null) {
		if(!$this->user->isLogged()) {
			$this->data['status'] = "error";
			$this->data['error'] = "Вы не авторизированы!";
			return json_encode($this->data);
		}
		
		if($this->user->getAccessLevel() < 0) {
	  		$this->data['status'] = "error";
			$this->data['error'] = "У вас нет доступа к данному разделу!";
			return json_encode($this->data);
		}
		
		$this->load->model('servers');
		
		$error = $this->validate($serverid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'servers/index');
		}
		
		$server = $this->serversModel->getServerById($serverid);
		
		if($server["server_status"] == 0) {
			$this->data["status"] = "error";
			$this->data["error"] = "Сервер заблокирован!";
			return json_encode($this->data);
		}
					
		switch($action) {
			case 'mysqlon': {
				if($server['server_mysql'] == 2) {
					$this->serversModel->updateServer($serverid, array('server_mysql' => 1));
					$this->data['status'] = "success";
					$this->data['success'] = "Вы успешно включили MySQL!";
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "MySQL и так включен либо вы его еще не создали!";
				}
				break;
			}	
			case 'mysqloff': {
				if($server['server_mysql'] == 1) {
					$this->serversModel->updateServer($serverid, array('server_mysql' => 2));
					$this->data['status'] = "success";
					$this->data['success'] = "Вы успешно выключили MySQL!";
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "MySQL и так выключен!";
				}
				break;
			}		
			case 'mysqlcr': {
				if($server['server_mysql'] == 0) {
					$this->serversModel->action($serverid, 'create_mysql');
					$this->serversModel->updateServer($serverid, array('server_mysql' => 2));
					$this->data['status'] = "success";
					$this->data['success'] = "Вы успешно создали MySQL! (БД: gs$serverid)";
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "MySQL и так создан!";
				}
				break;
			}				
			default: {
				$this->data['status'] = "error";
				$this->data['error'] = "Вы выбрали несуществующее действие!";
				break;
			}
		}
		return json_encode($this->data);
	}
	

	private function validate($serverid) {
		$result = null;
		
		$userid = $this->user->getId();
		
		if(!$this->serversModel->getTotalServerOwners(array('server_id' => (int)$serverid, 'user_id' => (int)$userid, 'owner_status' => 1))) {
			if(!$this->serversModel->getTotalServers(array('server_id' => (int)$serverid, 'user_id' => (int)$userid))) {
				$result = "Запрашиваемый сервер не существует!";
			}
		}
		return $result;
	}

}
?>
