<?php
/*
Copyright (c) 2020 HACKCHIK (https://hackchik.ru)
Developed by Andrey Chikaev (https://vk.com/winchikplay)
*/
class versionsController extends Controller {
	public function index($serverid = null) {
		$this->document->setActiveSection('servers');
		$this->document->setActiveItem('versions');
		
		if(!$this->user->isLogged()) {
			$this->session->data['error'] = "Вы не авторизированы!";
			$this->response->redirect($this->config->url . 'account/login');
		}
		if($this->user->getAccessLevel() < 0) {
			$this->session->data['error'] = "У вас нет доступа к данному разделу!";
			$this->response->redirect($this->config->url);
		}
		
		$this->load->model('servers');
		$this->load->model('versions');

		$error = $this->validate($serverid);
		if($error) {
			$this->session->data['error'] = $error;
			$this->response->redirect($this->config->url . 'servers/index');
		}	
		
		$server = $this->serversModel->getServerById($serverid, array('games', 'locations'));
		$versions = $this->versionsModel->getVersions(array('version_status' => 1), array('games'), array(), array());
        $this->data['versions'] = $versions;
		$this->data['server'] = $server;
		
		include_once 'application/controllers/common/main.php';
		
		$this->getChild(array('common/header', 'common/footer'));
		return $this->load->view('servers/versions', $this->data);
	}
	
	public function action($serverid = null, $action = null) {
		if(!$this->user->isLogged()) {
			$this->data['status'] = "error";
			$this->data['error'] = "Вы не авторизированы!";
			return json_encode($this->data);
		}
		if($this->user->getAccessLevel() < 0) {
	  		$this->data['status'] = "error";
			$this->data['error'] = "У вас нет доступа к данному разделу!";
			return json_encode($this->data);
		}
		$userid = $this->user->getId();
		$this->load->model('servers');
		$this->load->library('ssh2');
		$this->load->model('versions');
		$this->load->model('users');
		$this->load->model('waste');
		$this->load->model('serverLog');
		$ssh2Lib = new ssh2Library();

		$balance = $this->user->getBalance();
		$server = $this->serversModel->getServerById($serverid, array('users', 'locations', 'games'));
		
		$error = $this->validate($serverid);
		if($error) {
			$this->data['status'] = "error";
			$this->data['error'] = $error;
			return json_encode($this->data);
		}	
		
		if($server["server_status"] == 0) {
			$this->data["status"] = "error";
			$this->data["error"] = "Сервер заблокирован!";
			return json_encode($this->data);
		}
		
        $link = $ssh2Lib->connect($server['location_ip'], $server['location_user'], $server['location_password']);
        $versions = $this->versionsModel->getVersions(array(), array('games'), array(), array());
		foreach($versions as $item){
			if($action == $item['version_id']) {
				if($server['server_status'] == 1) {
					if($item['version_price'] > 0) {
						$price = $item['version_price'];
						if($balance < $price){
							$this->data['status'] = "error";
							$this->data['error'] = "Недостаточно средств";
							return json_encode($this->data);
						}
					}
					$this->load->library('ssh2');
					$ssh2Lib = new ssh2Library();
					$ssh2Lib->execute($link, 
					"
						cd /home/gs$serverid;
						chattr -i ".$server['check_files'].";						
					");
					$ssh2Lib->disconnect($link);
					$this->serversModel->updateServer($serverid, array('game_id' => $item['game_id_to']));
					$result = $this->serversModel->action($serverid, 'reinstall');		
					if($result['status'] == "success") {
						if($item['version_price'] > 0) {
							$userid = $this->user->getId();
							$wasteData = array(
							  'user_id'			=> $userid,
							  'waste_ammount'	=> $price,
							  'waste_status'	=> 1,
							  'waste_usluga'	=> "Смена игры на ".$item['version_name'].""
							); 
							$this->wasteModel->createWaste($wasteData);
							$logData = array(
								'server_id'			=> $serverid,
								'reason'            => 'Успешная смена игры.',
								'status'            => 2
							);
							$this->serverLogModel->createLog($logData);
							$this->usersModel->downUserBalance($userid, $price);
							$this->data['status'] = "success";
							$this->data['success'] = "Вы успешно сменили игру на ".$item['version_name']." с вашего счёта снято ".$item['version_price']." р!";
						} else {
							$logData = array(
								'server_id'			=> $serverid,
								'reason'            => 'Успешная смена игры.',
								'status'            => 2
							);
							$this->serverLogModel->createLog($logData);
							$this->data['status'] = "success";
							$this->data['success'] = "Вы сменили игру на ".$item['version_name']."!";
						}	
					}
				} else {
					$this->data['status'] = "error";
					$this->data['error'] = "Сервер должен быть выключен!";
			    }
            }
		}
		return json_encode($this->data);
	}

	private function validate($serverid) {
		$result = null;
		
		$userid = $this->user->getId();
		
		if(!$this->serversModel->getTotalServerOwners(array('server_id' => (int)$serverid, 'user_id' => (int)$userid, 'owner_status' => 1))) {
			if(!$this->serversModel->getTotalServers(array('server_id' => (int)$serverid, 'user_id' => (int)$userid))) {
				$result = "Запрашиваемый сервер не существует!";
			}
		}
		return $result;
	}
}
?>